searchData={"items":[{"type":"module","title":"ExUrlbox","doc":"A light wrapper for the Urlbox API.\n\n**Compatible with Urlbox API Version:** `v1`\n\nA list of options that you can pass into `ExUrlbox.get/3`, `ExUrlbox.post/3`, `ExUrlbox.head/3`, and `ExUrlbox.delete/3` can be found here:\nhttps://urlbox.io/docs/options","ref":"ExUrlbox.html"},{"type":"function","title":"ExUrlbox.delete/3","doc":"Urlbox will cache previously created screenshots for some time. Sending a delete request removes a previously created screenshot from the cache.\n\n  - Example request:\n  ```\n  ExUrlbox.delete(\"https://anthonymineo.com\")\n  ```","ref":"ExUrlbox.html#delete/3"},{"type":"function","title":"ExUrlbox.get/3","doc":"Send a request to Urlbox for a screenshot.\nRefer to the official documentation for all the available options: https://urlbox.io/docs/options\n\n  **This action is `synchronous`. **\n  If you want to use an `async` flow that uses webhooks, use `ExUrlbox.post/3`.\n\n **Function signature is: `url, [options], timeout`**\n\n  - Example request:\n  ```\n  ExUrlbox.get(\"https://anthonymineo.com\")\n  ```\n\n  - Example with options:\n  ```\n  ExUrlbox.get(\"https://anthonymineo.com\", [format: \"png\", full_page: true])\n  ```\n\n  - Example with timeout (5s):\n  ```\n  ExUrlbox.get(\"https://anthonymineo.com\", [], 5_000)\n  ```","ref":"ExUrlbox.html#get/3"},{"type":"function","title":"ExUrlbox.head/3","doc":"If you just want to get the response status/headers without pulling down the full response body.\n\n  - Example request:\n  ```\n  ExUrlbox.head(\"https://anthonymineo.com\")\n  ```","ref":"ExUrlbox.html#head/3"},{"type":"function","title":"ExUrlbox.post/3","doc":"Post a request to Urlbox for a screenshot.\nYou should provide a `webhook_url` option to receive a postback to once the screenshot render is complete.\n\n**This action is `async`. **\n\n  - Example request with options containing `webhook_url` for a postback:\n  ```\n  ExUrlbox.post(\"https://anthonymineo.com\", [webhook_url: \"https://app-waiting-for-incoming-post.com/\"])\n  ```\n\n  - Initial response from a post:\n  ```\n  {\n    \"renderId\": \"ebcbce5q-9657-435f-aeb6-5db207ee87b5\",\n    \"status\": \"created\",\n    \"statusUrl\": \"https://api.urlbox.io/render/ebcbce5q-9657-435f-aeb6-5db207ee87b5\"\n  }\n  ```\n\n  - If you dont provide a `webhook_url` you will need to poll the `statusUrl` for the status of your request:\n  ```\n  {\n    \"renderId\": \"ebcbce5q-9657-435f-aeb6-5db207ee87b5\",\n    \"status\":\t\"succeeded\",\n    \"renderUrl\": \"https://renders.urlbox.io/urlbox1/renders/a1d7g7d45f7am5a0a69cd3de/2022/5/7/ebcbce5q-9657-435f-aeb6-5db207ee87b5.png\",\n    \"size\": 34748\n  }\n  ```\n\n  - Example of a postback to `webhook_url`:\n  ```\n  {\n    \"event\": \"render.succeeded\",\n    \"renderId\": \"ebcbce5q-9657-435f-aeb6-5db207ee87b5\",\n    \"result\": {\n      \"renderUrl\": \"https://renders.urlbox.io/urlbox1/renders/a1d7g7d45f7am5a0a69cd3de/2022/5/7/ebcbce5q-9657-435f-aeb6-5db207ee87b5.png\",\n      \"size\": 34748\n    },\n    \"meta\": {\n      \"startTime\":\"2022-05-07T20:25:28.879Z\",\n      \"endTime\":\"2022-05-07T20:25:31.646Z\"\n    }\n  }\n  ```","ref":"ExUrlbox.html#post/3"},{"type":"module","title":"ExUrlbox.Config","doc":"Retrieve config variables that are used with Urlbox's API.\n\nAll settings also accept `{:system, \"ENV_VAR_NAME\"}` to read their\nvalues from environment variables at runtime.","ref":"ExUrlbox.Config.html"},{"type":"function","title":"ExUrlbox.Config.api_key/0","doc":"Returns the *URLBOX_API_KEY*\n    config :ex_urlbox, api_key: \"URLBOX_API_KEY\"","ref":"ExUrlbox.Config.html#api_key/0"},{"type":"function","title":"ExUrlbox.Config.api_key_endpoint/0","doc":"Returns the API endpoint with api_key for the following HTTP methods: GET, DELETE, HEAD","ref":"ExUrlbox.Config.html#api_key_endpoint/0"},{"type":"function","title":"ExUrlbox.Config.api_post_endpoint/0","doc":"Urlbox's API path for POST requests","ref":"ExUrlbox.Config.html#api_post_endpoint/0"},{"type":"function","title":"ExUrlbox.Config.api_secret/0","doc":"Returns the *URLBOX_API_SECRET*\n    config :ex_urlbox, api_secret: \"URLBOX_API_SECRET\"","ref":"ExUrlbox.Config.html#api_secret/0"},{"type":"function","title":"ExUrlbox.Config.base_endpoint/0","doc":"Returns the default API endpoint. Used with POST requests","ref":"ExUrlbox.Config.html#base_endpoint/0"},{"type":"function","title":"ExUrlbox.Config.from_env/3","doc":"A light wrapper around `Application.get_env/2`, providing automatic support for\n`{:system, \"VAR\"}` tuples.","ref":"ExUrlbox.Config.html#from_env/3"},{"type":"function","title":"ExUrlbox.Config.get_client_adapter/1","doc":"Returns the appropriate Tesla adapter based on the environment.\nIn test environment, returns Tesla.Mock.\nIn other environments, returns the configured adapter or defaults to Hackney.","ref":"ExUrlbox.Config.html#get_client_adapter/1"},{"type":"module","title":"ExUrlbox.Utils","doc":"Various helper utilities for working with Urlbox's API","ref":"ExUrlbox.Utils.html"},{"type":"function","title":"ExUrlbox.Utils.build_url/1","doc":"Build the screenshot request URL. Used with `get`, `delete` and `head` requests.\n\n  - Example URL:\n  ```html\n  /png?url=https%3A%2F%2Fgoogle.com&width=1024&height=768\"\n  ```","ref":"ExUrlbox.Utils.html#build_url/1"},{"type":"function","title":"ExUrlbox.Utils.generate_url_token/1","doc":"Generates a URL token by taking the HMAC SHA1 of the query string and signing it with your :api_secret.\n\n  - Example URL Format:\n  ```html\n  https://api.urlbox.io/v1/:api_key/hmac(:api_secret)/format?[options]\n  ```","ref":"ExUrlbox.Utils.html#generate_url_token/1"},{"type":"extras","title":"ExUrlbox","doc":"# ExUrlbox\n[![Elixir Tests / Static Analysis](https://github.com/amineo/ex_urlbox/actions/workflows/elixir.yml/badge.svg?branch=main)](https://github.com/amineo/ex_urlbox/actions/workflows/elixir.yml)\n\n  A light wrapper for the Urlbox API written in Elixir. ExUrlbox's documentation could be found on [HexDocs](https://hexdocs.pm/ex_urlbox).\n\n  **Compatible with Urlbox API:** `v1`\n\n  A list of options that you can pass into `ExUrlbox.get/3`, `ExUrlbox.post/3`, `ExUrlbox.head/3`, and `ExUrlbox.delete/3` can be found here:\n  https://urlbox.io/docs/options","ref":"readme.html"},{"type":"extras","title":"Installation - ExUrlbox","doc":"This package can be installed by adding `ex_urlbox` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_urlbox, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configure the Urlbox API Key and Secret - ExUrlbox","doc":"You can find your API Key and Secret [here](https://urlbox.io/dashboard/api).\n\n**Environment Vars (.env) -- refer to (.env.example)**\n```\nURLBOX_API_KEY=\"YoUrApIKeY\"\nURLBOX_API_SECRET=\"YoUrApISeCreT\"\n```\n\n**ExUrlbox will automatically look for the env vars listed above using the config below**\n```elixir\nconfig :ex_urlbox,\n  api_key: {:system, \"URLBOX_API_KEY\"},\n  api_secret: {:system, \"URLBOX_API_SECRET\"}\n```","ref":"readme.html#configure-the-urlbox-api-key-and-secret"},{"type":"extras","title":"Example Usage - ExUrlbox","doc":"","ref":"readme.html#example-usage"},{"type":"extras","title":"GET - Synchronous - ExUrlbox","doc":"```elixir\n  # Simple\n  ExUrlbox.get(\"https://anthonymineo.com\")\n\n  # With options:\n  ExUrlbox.get(\"https://anthonymineo.com\", [format: \"png\", full_page: true])\n\n  # With a timeout (5s):\n  ExUrlbox.get(\"https://anthonymineo.com\", [], 5_000)\n\n\n  # Extract data from a response\n  {:ok, screenshot} = ExUrlbox.get(\"https://anthonymineo.com\")\n\n  screenshot.body\n  # => <<137, 80, 78, 71, 13, ...>>>\n\n  screenshot.headers\n  # => [{\"content-type\", \"image/png\"}, ...]\n\n  screenshot.url\n  # => https://api.urlbox.io/v1/:apikey/hmac(:apisecret)/png?url=https%3A%2F%2Fwww.google.com&width=1024&height=768\n\n  ```","ref":"readme.html#get-synchronous"},{"type":"extras","title":"POST - Async with a webhook - ExUrlbox","doc":"Post a request to Urlbox for a screenshot.\n  You should provide a `webhook_url` option to receive a postback to once the screenshot render is complete.\n  ```elixir\n  # Example request with options containing `webhook_url` for a postback:\n  ExUrlbox.post(\"https://anthonymineo.com\", [webhook_url: \"https://app-waiting-for-incoming-post.com/\"])\n  ```\n\n  **Initial response from a post:**\n  ```json\n  {\n    \"renderId\": \"ebcbce5q-9657-435f-aeb6-5db207ee87b5\",\n    \"status\": \"created\",\n    \"statusUrl\": \"https://api.urlbox.io/render/ebcbce5q-9657-435f-aeb6-5db207ee87b5\"\n  }\n```\n\n**Example postback to `webhook_url`:**\n```json\n{\n  \"event\": \"render.succeeded\",\n  \"renderId\": \"ebcbce5q-9657-435f-aeb6-5db207ee87b5\",\n  \"result\": {\n    \"renderUrl\": \"https://renders.urlbox.io/urlbox1/renders/a1d7g7d45f7am5a0a69cd3de/2022/5/7/ebcbce5q-9657-435f-aeb6-5db207ee87b5.png\",\n    \"size\": 34748\n  },\n  \"meta\": {\n    \"startTime\":\"2022-05-07T20:25:28.879Z\",\n    \"endTime\":\"2022-05-07T20:25:31.646Z\"\n  }\n}\n```\n\n\n**NOTE: If you dont provide a `webhook_url` you will need to poll the `statusUrl` that's included in the initial post response for the status of your request:**\n```json\n/* GET => statusUrl */\n{\n  \"renderId\": \"ebcbce5q-9657-435f-aeb6-5db207ee87b5\",\n  \"status\":\t\"succeeded\",\n  \"renderUrl\": \"https://renders.urlbox.io/urlbox1/renders/a1d7g7d45f7am5a0a69cd3de/2022/5/7/ebcbce5q-9657-435f-aeb6-5db207ee87b5.png\",\n  \"size\": 34748\n}\n```","ref":"readme.html#post-async-with-a-webhook"},{"type":"extras","title":"DELETE - ExUrlbox","doc":"Urlbox will cache previously created screenshots for some time. Sending a delete request removes a previously created screenshot from the cache.\n\n**Example request:**\n```elixir\nExUrlbox.delete(\"https://anthonymineo.com\")\n```","ref":"readme.html#delete"},{"type":"extras","title":"HEAD - ExUrlbox","doc":"If you just want to get the response status/headers without pulling down the full response body.\n\n**Example request:**\n```elixir\nExUrlbox.head(\"https://anthonymineo.com\")\n```","ref":"readme.html#head"},{"type":"extras","title":"Docs - ExUrlbox","doc":"The full docs can be found at [https://hexdocs.pm/ex_urlbox](https://hexdocs.pm/ex_urlbox).\n\nDocumentation has been generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm).","ref":"readme.html#docs"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.0"}}